@@ -4,4 +4,4 @@ from pyformance.meters import Counter, Histogram, Meter, Timer
 from mogwai.exceptions import MogwaiMetricsException
 
 # Default Reporter
-from base import ConsoleMetricReporter
+from .base import ConsoleMetricReporter
