@@ -1,11 +1,11 @@
 # -*- coding: utf-8 -*-
 from __future__ import unicode_literals
+from mogwai._compat import print_
 from nose.plugins.attrib import attr
-from nose.tools import nottest
 
 from mogwai import connection
 from mogwai.exceptions import MogwaiException
-from mogwai.tests.base import BaseMogwaiTestCase, TestVertexModel, TestEdgeModel
+from mogwai.tests.base import BaseMogwaiTestCase, TestVertexModel, TestEdgeModel, TestVertexModelDouble
 
 from mogwai import gremlin
 from mogwai import models
@@ -140,6 +140,22 @@ class TestVertexIO(BaseMogwaiTestCase):
         v1.delete()
         v2.delete()
 
+    def test_find_by_value_method(self):
+        v1 = TestVertexModel.create(name='v1', test_val=-99)
+        v2 = TestVertexModel.create(name='v2', test_val=-99)
+        v3 = TestVertexModelDouble.create(name='v3', test_val=-100.0)
+
+        self.assertEqual(len(TestVertexModel.find_by_value('name', 'v1')), 1)
+        self.assertEqual(len(TestVertexModel.find_by_value('test_val', -99)), 2)
+        self.assertEqual(len(TestVertexModel.find_by_value('name', 'bar')), 0)
+
+        self.assertEqual(TestVertexModel.find_by_value('name', 'v1')[0], v1)
+
+        self.assertEqual(len(TestVertexModelDouble.find_by_value('test_val', -100.0)), 1)
+        v1.delete()
+        v2.delete()
+        v3.delete()
+
     def test_get_by_id(self):
         v1 = TestVertexModel.create()
         results = TestVertexModel.get(v1.id)
@@ -507,4 +523,62 @@ class TestVertexTraversal(BaseMogwaiTestCase):
 
         e1.delete()
         e2.delete()
-        e3.delete()
\ No newline at end of file
+        e3.delete()
+
+    @attr('manual_properties')
+    def test_manual_properties(self):
+        v = TestVertexModel.create(test_val=1, name='Test 7', some_property=32)
+
+        print_("Got Results: {}".format(v))
+        print_("Result dict: {}".format(v.as_dict()))
+        print_("\tResult properties: {}".format(v._properties.keys()))
+        print_("\tResult Manaul: {}".format(v._manual_values.items()))
+
+        self.assertEqual(v['some_property'], 32)
+        self.assertIn('some_property', v)  # This also tests __contains__
+        self.assertIn('test_val', v)  # This also tests __contains__
+
+        # test len(Element()), should return len(element._properties) + len(element._manual_values)
+        self.assertEqual(len(v), 3)
+
+        # test __iter__
+        prop_keys = [key for key in v]
+        self.assertEqual(len(prop_keys), 3)
+        for prop_key in v:
+            self.assertIn(prop_key, ['test_val', 'name', 'some_property'])
+
+        # test keys()
+        self.assertEqual(len(prop_keys), len(v.keys()))
+        for prop_key in v.keys():
+            self.assertIn(prop_key, prop_keys)
+
+        # test values()
+        prop_values = v.values()
+        self.assertEqual(len(prop_values), 3)
+        for prop_value in prop_values:
+            self.assertIn(prop_value, [1, 'Test 7', 32])
+
+        # test items()
+        prop_items = v.items()
+        self.assertEqual(len(prop_items), 3)
+        for prop_key, prop_value in prop_items:
+            self.assertIn(prop_key, ['test_val', 'name', 'some_property'])
+            self.assertIn(prop_value, [1, 'Test 7', 32])
+
+        # test change
+        v['some_property'] = 42
+        self.assertEqual(v['some_property'], 42)
+        v.save()
+        self.assertEqual(v['some_property'], 42)
+
+        # test delete
+        del v['some_property']
+        # This should still exist, so the property can be removed from the database,
+        # but should raise an AttributeError if attempted to access normally
+        self.assertIn('some_property', v)
+        self.assertIsNone(v._manual_values.get('some_property'))
+        with self.assertRaises(AttributeError):
+            value = v['some_property']
+            print_("Got value: {}".format(value))
+
+        v.delete()
